# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime

import httpx

from ..types import (
    medical_record_update_params,
    medical_record_retrieve_params,
    medical_record_create_list_params,
    medical_record_ongoing_record_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.medical_record_retrieve_response import MedicalRecordRetrieveResponse
from ..types.medical_record_create_list_response import MedicalRecordCreateListResponse

__all__ = ["MedicalRecordsResource", "AsyncMedicalRecordsResource"]


class MedicalRecordsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MedicalRecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return MedicalRecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MedicalRecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return MedicalRecordsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        report_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MedicalRecordRetrieveResponse:
        """
        获取单个病例报告

        Args:
          report_id: 报告 ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/medical-record",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"report_id": report_id}, medical_record_retrieve_params.MedicalRecordRetrieveParams
                ),
            ),
            cast_to=MedicalRecordRetrieveResponse,
        )

    def update(
        self,
        *,
        is_read: int | NotGiven = NOT_GIVEN,
        report_id: int | NotGiven = NOT_GIVEN,
        report_time: Union[str, datetime] | NotGiven = NOT_GIVEN,
        stage: str | NotGiven = NOT_GIVEN,
        status: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        修改状态和记录对话进行阶段

        Args:
          report_id: 医疗报告 ID

          stage: 阶段存档

          status: 1-进行中 2-已完成 3-手动结束 4-自动结束

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            "/medical-record",
            body=maybe_transform(
                {
                    "is_read": is_read,
                    "report_id": report_id,
                    "report_time": report_time,
                    "stage": stage,
                    "status": status,
                },
                medical_record_update_params.MedicalRecordUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def create_list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        module_type: Iterable[int] | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        pet_profile_id: Iterable[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MedicalRecordCreateListResponse:
        """
        获取医疗报告列表

        Args:
          limit: 每页数量

          page: 页码

          pet_profile_id: 宠物档案 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/medical-record-list",
            body=maybe_transform(
                {
                    "limit": limit,
                    "module_type": module_type,
                    "page": page,
                    "pet_profile_id": pet_profile_id,
                },
                medical_record_create_list_params.MedicalRecordCreateListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MedicalRecordCreateListResponse,
        )

    def ongoing_record(
        self,
        *,
        module_type: int,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取进行中的医疗报告

        Args:
          module_type: 模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          pet_profile_id: 宠物档案 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/medical-record/ongoing-record",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "module_type": module_type,
                        "pet_profile_id": pet_profile_id,
                    },
                    medical_record_ongoing_record_params.MedicalRecordOngoingRecordParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsyncMedicalRecordsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMedicalRecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMedicalRecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMedicalRecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncMedicalRecordsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        report_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MedicalRecordRetrieveResponse:
        """
        获取单个病例报告

        Args:
          report_id: 报告 ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/medical-record",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"report_id": report_id}, medical_record_retrieve_params.MedicalRecordRetrieveParams
                ),
            ),
            cast_to=MedicalRecordRetrieveResponse,
        )

    async def update(
        self,
        *,
        is_read: int | NotGiven = NOT_GIVEN,
        report_id: int | NotGiven = NOT_GIVEN,
        report_time: Union[str, datetime] | NotGiven = NOT_GIVEN,
        stage: str | NotGiven = NOT_GIVEN,
        status: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        修改状态和记录对话进行阶段

        Args:
          report_id: 医疗报告 ID

          stage: 阶段存档

          status: 1-进行中 2-已完成 3-手动结束 4-自动结束

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            "/medical-record",
            body=await async_maybe_transform(
                {
                    "is_read": is_read,
                    "report_id": report_id,
                    "report_time": report_time,
                    "stage": stage,
                    "status": status,
                },
                medical_record_update_params.MedicalRecordUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def create_list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        module_type: Iterable[int] | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        pet_profile_id: Iterable[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MedicalRecordCreateListResponse:
        """
        获取医疗报告列表

        Args:
          limit: 每页数量

          page: 页码

          pet_profile_id: 宠物档案 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/medical-record-list",
            body=await async_maybe_transform(
                {
                    "limit": limit,
                    "module_type": module_type,
                    "page": page,
                    "pet_profile_id": pet_profile_id,
                },
                medical_record_create_list_params.MedicalRecordCreateListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MedicalRecordCreateListResponse,
        )

    async def ongoing_record(
        self,
        *,
        module_type: int,
        pet_profile_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取进行中的医疗报告

        Args:
          module_type: 模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别

          pet_profile_id: 宠物档案 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/medical-record/ongoing-record",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "module_type": module_type,
                        "pet_profile_id": pet_profile_id,
                    },
                    medical_record_ongoing_record_params.MedicalRecordOngoingRecordParams,
                ),
            ),
            cast_to=NoneType,
        )


class MedicalRecordsResourceWithRawResponse:
    def __init__(self, medical_records: MedicalRecordsResource) -> None:
        self._medical_records = medical_records

        self.retrieve = to_raw_response_wrapper(
            medical_records.retrieve,
        )
        self.update = to_raw_response_wrapper(
            medical_records.update,
        )
        self.create_list = to_raw_response_wrapper(
            medical_records.create_list,
        )
        self.ongoing_record = to_raw_response_wrapper(
            medical_records.ongoing_record,
        )


class AsyncMedicalRecordsResourceWithRawResponse:
    def __init__(self, medical_records: AsyncMedicalRecordsResource) -> None:
        self._medical_records = medical_records

        self.retrieve = async_to_raw_response_wrapper(
            medical_records.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            medical_records.update,
        )
        self.create_list = async_to_raw_response_wrapper(
            medical_records.create_list,
        )
        self.ongoing_record = async_to_raw_response_wrapper(
            medical_records.ongoing_record,
        )


class MedicalRecordsResourceWithStreamingResponse:
    def __init__(self, medical_records: MedicalRecordsResource) -> None:
        self._medical_records = medical_records

        self.retrieve = to_streamed_response_wrapper(
            medical_records.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            medical_records.update,
        )
        self.create_list = to_streamed_response_wrapper(
            medical_records.create_list,
        )
        self.ongoing_record = to_streamed_response_wrapper(
            medical_records.ongoing_record,
        )


class AsyncMedicalRecordsResourceWithStreamingResponse:
    def __init__(self, medical_records: AsyncMedicalRecordsResource) -> None:
        self._medical_records = medical_records

        self.retrieve = async_to_streamed_response_wrapper(
            medical_records.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            medical_records.update,
        )
        self.create_list = async_to_streamed_response_wrapper(
            medical_records.create_list,
        )
        self.ongoing_record = async_to_streamed_response_wrapper(
            medical_records.ongoing_record,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AidocExoticKeywordsResponse", "Data"]


class Data(BaseModel):
    keywords: Optional[str] = None
    """关键词"""

    unit: Optional[str] = None
    """科室"""


class AidocExoticKeywordsResponse(BaseModel):
    data: Optional[Data] = None

    message: Optional[str] = None

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import (
    PetProfileListResponse,
    PetProfileDeleteResponse,
    PetProfileRetrieveResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPetProfiles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.create()
        assert pet_profile is None

    @parametrize
    def test_method_create_with_all_params(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.create(
            allergy_history="allergy_history",
            avatar="avatar",
            birthday="birthday",
            disease_history="disease_history",
            family_history="family_history",
            gender=0,
            is_neutered=0,
            is_vaccination=0,
            name="name",
            pet_type=0,
            pet_variety="pet_variety",
            vaccination_date="vaccination_date",
            weight="weight",
        )
        assert pet_profile is None

    @parametrize
    def test_raw_response_create(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert pet_profile is None

    @parametrize
    def test_streaming_response_create(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.retrieve(
            pet_profile_id=0,
        )
        assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.retrieve(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.retrieve(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.update(
            pet_profile_id=0,
        )
        assert pet_profile is None

    @parametrize
    def test_method_update_with_all_params(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.update(
            pet_profile_id=0,
            allergy_history="allergy_history",
            avatar="avatar",
            birthday="birthday",
            disease_history="disease_history",
            family_history="family_history",
            gender=0,
            is_neutered=0,
            is_vaccination=0,
            name="name",
            pet_type=0,
            pet_variety="pet_variety",
            vaccination_date="vaccination_date",
            weight="weight",
        )
        assert pet_profile is None

    @parametrize
    def test_raw_response_update(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.update(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert pet_profile is None

    @parametrize
    def test_streaming_response_update(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.update(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.list()
        assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.delete(
            pet_profile_id=0,
        )
        assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.delete(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.delete(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_ex_info(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.ex_info()
        assert pet_profile is None

    @parametrize
    def test_method_ex_info_with_all_params(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.ex_info(
            pet_profile_id=0,
        )
        assert pet_profile is None

    @parametrize
    def test_raw_response_ex_info(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.ex_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert pet_profile is None

    @parametrize
    def test_streaming_response_ex_info(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.ex_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_variety(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.variety()
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_variety_with_all_params(self, client: Czlai) -> None:
        pet_profile = client.pet_profiles.variety(
            user_input="虎皮鹦鹉",
        )
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_variety(self, client: Czlai) -> None:
        response = client.pet_profiles.with_raw_response.variety()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = response.parse()
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_variety(self, client: Czlai) -> None:
        with client.pet_profiles.with_streaming_response.variety() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = response.parse()
            assert_matches_type(str, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncPetProfiles:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.create()
        assert pet_profile is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.create(
            allergy_history="allergy_history",
            avatar="avatar",
            birthday="birthday",
            disease_history="disease_history",
            family_history="family_history",
            gender=0,
            is_neutered=0,
            is_vaccination=0,
            name="name",
            pet_type=0,
            pet_variety="pet_variety",
            vaccination_date="vaccination_date",
            weight="weight",
        )
        assert pet_profile is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert pet_profile is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.retrieve(
            pet_profile_id=0,
        )
        assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.retrieve(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.retrieve(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert_matches_type(PetProfileRetrieveResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.update(
            pet_profile_id=0,
        )
        assert pet_profile is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.update(
            pet_profile_id=0,
            allergy_history="allergy_history",
            avatar="avatar",
            birthday="birthday",
            disease_history="disease_history",
            family_history="family_history",
            gender=0,
            is_neutered=0,
            is_vaccination=0,
            name="name",
            pet_type=0,
            pet_variety="pet_variety",
            vaccination_date="vaccination_date",
            weight="weight",
        )
        assert pet_profile is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.update(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert pet_profile is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.update(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.list()
        assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert_matches_type(PetProfileListResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.delete(
            pet_profile_id=0,
        )
        assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.delete(
            pet_profile_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.delete(
            pet_profile_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert_matches_type(PetProfileDeleteResponse, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_ex_info(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.ex_info()
        assert pet_profile is None

    @parametrize
    async def test_method_ex_info_with_all_params(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.ex_info(
            pet_profile_id=0,
        )
        assert pet_profile is None

    @parametrize
    async def test_raw_response_ex_info(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.ex_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert pet_profile is None

    @parametrize
    async def test_streaming_response_ex_info(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.ex_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert pet_profile is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_variety(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.variety()
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_variety_with_all_params(self, async_client: AsyncCzlai) -> None:
        pet_profile = await async_client.pet_profiles.variety(
            user_input="虎皮鹦鹉",
        )
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_variety(self, async_client: AsyncCzlai) -> None:
        response = await async_client.pet_profiles.with_raw_response.variety()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pet_profile = await response.parse()
        assert_matches_type(str, pet_profile, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_variety(self, async_client: AsyncCzlai) -> None:
        async with async_client.pet_profiles.with_streaming_response.variety() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pet_profile = await response.parse()
            assert_matches_type(str, pet_profile, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from czlai.types import PointPriceRetrieveResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPointPrices:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: Czlai) -> None:
        point_price = client.point_prices.retrieve()
        assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Czlai) -> None:
        response = client.point_prices.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_price = response.parse()
        assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Czlai) -> None:
        with client.point_prices.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_price = response.parse()
            assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncPointPrices:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCzlai) -> None:
        point_price = await async_client.point_prices.retrieve()
        assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCzlai) -> None:
        response = await async_client.point_prices.with_raw_response.retrieve()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        point_price = await response.parse()
        assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCzlai) -> None:
        async with async_client.point_prices.with_streaming_response.retrieve() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            point_price = await response.parse()
            assert_matches_type(PointPriceRetrieveResponse, point_price, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AIMemeGenerateParams"]


class AIMemeGenerateParams(TypedDict, total=False):
    context_index: int
    """文案序号"""

    meme_id: int
    """表情包 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["LoginSMSParams"]


class LoginSMSParams(TypedDict, total=False):
    code: Required[str]

    phone: Required[str]

    login_from: int
    """1-微信小程序 2-安卓 APP 3-IOS APP"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ai_meme import AIMeme as AIMeme
from .pet_profile import PetProfile as PetProfile
from .login_response import LoginResponse as LoginResponse
from .medical_record import MedicalRecord as MedicalRecord
from .login_sms_params import LoginSMSParams as LoginSMSParams
from .user_chat_v_params import UserChatVParams as UserChatVParams
from .aidoc_report_params import AidocReportParams as AidocReportParams
from .aipic_report_params import AipicReportParams as AipicReportParams
from .login_wechat_params import LoginWechatParams as LoginWechatParams
from .aipic_options_params import AipicOptionsParams as AipicOptionsParams
from .aipic_summary_params import AipicSummaryParams as AipicSummaryParams
from .upload_create_params import UploadCreateParams as UploadCreateParams
from .user_send_sms_params import UserSendSMSParams as UserSendSMSParams
from .ai_conv_answer_params import AIConvAnswerParams as AIConvAnswerParams
from .ai_meme_create_params import AIMemeCreateParams as AIMemeCreateParams
from .aipic_question_params import AipicQuestionParams as AipicQuestionParams
from .aipic_validate_params import AipicValidateParams as AipicValidateParams
from .ai_trial_answer_params import AITrialAnswerParams as AITrialAnswerParams
from .ai_trial_report_params import AITrialReportParams as AITrialReportParams
from .ai_conv_answer_response import AIConvAnswerResponse as AIConvAnswerResponse
from .ai_conv_relation_params import AIConvRelationParams as AIConvRelationParams
from .ai_conv_validate_params import AIConvValidateParams as AIConvValidateParams
from .ai_meme_create_response import AIMemeCreateResponse as AIMemeCreateResponse
from .ai_meme_generate_params import AIMemeGenerateParams as AIMemeGenerateParams
from .ai_meme_retrieve_params import AIMemeRetrieveParams as AIMemeRetrieveParams
from .ai_trial_history_params import AITrialHistoryParams as AITrialHistoryParams
from .ai_trial_options_params import AITrialOptionsParams as AITrialOptionsParams
from .ai_trial_summary_params import AITrialSummaryParams as AITrialSummaryParams
from .aidoc_pic_result_params import AidocPicResultParams as AidocPicResultParams
from .aipic_pic_result_params import AipicPicResultParams as AipicPicResultParams
from .point_task_bonus_params import PointTaskBonusParams as PointTaskBonusParams
from .ai_checkup_report_params import AICheckupReportParams as AICheckupReportParams
from .ai_trial_answer_response import AITrialAnswerResponse as AITrialAnswerResponse
from .ai_trial_question_params import AITrialQuestionParams as AITrialQuestionParams
from .ai_trial_relation_params import AITrialRelationParams as AITrialRelationParams
from .aidoc_report_task_params import AidocReportTaskParams as AidocReportTaskParams
from .aipic_report_task_params import AipicReportTaskParams as AipicReportTaskParams
from .point_task_list_response import PointTaskListResponse as PointTaskListResponse
from .ai_checkup_summary_params import AICheckupSummaryParams as AICheckupSummaryParams
from .ai_meme_generate_response import AIMemeGenerateResponse as AIMemeGenerateResponse
from .ai_meme_retrieve_response import AIMemeRetrieveResponse as AIMemeRetrieveResponse
from .buriedpoint_create_params import BuriedpointCreateParams as BuriedpointCreateParams
from .check_point_create_params import CheckPointCreateParams as CheckPointCreateParams
from .magnum_key_get_key_params import MagnumKeyGetKeyParams as MagnumKeyGetKeyParams
from .pet_profile_create_params import PetProfileCreateParams as PetProfileCreateParams
from .pet_profile_delete_params import PetProfileDeleteParams as PetProfileDeleteParams
from .pet_profile_list_response import PetProfileListResponse as PetProfileListResponse
from .pet_profile_update_params import PetProfileUpdateParams as PetProfileUpdateParams
from .point_task_confirm_params import PointTaskConfirmParams as PointTaskConfirmParams
from .policy_policy_info_params import PolicyPolicyInfoParams as PolicyPolicyInfoParams
from .user_advice_create_params import UserAdviceCreateParams as UserAdviceCreateParams
from .ai_checkup_is_first_params import AICheckupIsFirstParams as AICheckupIsFirstParams
from .ai_checkup_question_params import AICheckupQuestionParams as AICheckupQuestionParams
from .aidoc_exotic_report_params import AidocExoticReportParams as AidocExoticReportParams
from .aidoc_if_need_image_params import AidocIfNeedImageParams as AidocIfNeedImageParams
from .aipic_exotic_report_params import AipicExoticReportParams as AipicExoticReportParams
from .pet_profile_ex_info_params import PetProfileExInfoParams as PetProfileExInfoParams
from .pet_profile_variety_params import PetProfileVarietyParams as PetProfileVarietyParams
from .upload_image_create_params import UploadImageCreateParams as UploadImageCreateParams
from .whitelist_save_data_params import WhitelistSaveDataParams as WhitelistSaveDataParams
from .ai_checkup_summary_response import AICheckupSummaryResponse as AICheckupSummaryResponse
from .aidoc_exotic_options_params import AidocExoticOptionsParams as AidocExoticOptionsParams
from .aipic_exotic_options_params import AipicExoticOptionsParams as AipicExoticOptionsParams
from .aipic_exotic_summary_params import AipicExoticSummaryParams as AipicExoticSummaryParams
from .pet_profile_delete_response import PetProfileDeleteResponse as PetProfileDeleteResponse
from .pet_profile_retrieve_params import PetProfileRetrieveParams as PetProfileRetrieveParams
from .ai_checkup_is_first_response import AICheckupIsFirstResponse as AICheckupIsFirstResponse
from .ai_checkup_pic_result_params import AICheckupPicResultParams as AICheckupPicResultParams
from .aidoc_exotic_keywords_params import AidocExoticKeywordsParams as AidocExoticKeywordsParams
from .aidoc_exotic_question_params import AidocExoticQuestionParams as AidocExoticQuestionParams
from .aidoc_if_continue_ask_params import AidocIfContinueAskParams as AidocIfContinueAskParams
from .aipic_exotic_question_params import AipicExoticQuestionParams as AipicExoticQuestionParams
from .aipic_exotic_validate_params import AipicExoticValidateParams as AipicExoticValidateParams
from .medical_record_update_params import MedicalRecordUpdateParams as MedicalRecordUpdateParams
from .pet_profile_variety_response import PetProfileVarietyResponse as PetProfileVarietyResponse
from .point_detail_retrieve_params import PointDetailRetrieveParams as PointDetailRetrieveParams
from .user_point_retrieve_response import UserPointRetrieveResponse as UserPointRetrieveResponse
from .ai_checkup_report_task_params import AICheckupReportTaskParams as AICheckupReportTaskParams
from .ai_trial_session_start_params import AITrialSessionStartParams as AITrialSessionStartParams
from .aidoc_exotic_options_response import AidocExoticOptionsResponse as AidocExoticOptionsResponse
from .aidoc_exotic_summarize_params import AidocExoticSummarizeParams as AidocExoticSummarizeParams
from .pet_profile_retrieve_response import PetProfileRetrieveResponse as PetProfileRetrieveResponse
from .point_price_retrieve_response import PointPriceRetrieveResponse as PointPriceRetrieveResponse
from .session_record_history_params import SessionRecordHistoryParams as SessionRecordHistoryParams
from .user_point_cost_report_params import UserPointCostReportParams as UserPointCostReportParams
from .aidoc_exotic_keywords_response import AidocExoticKeywordsResponse as AidocExoticKeywordsResponse
from .aidoc_exotic_pic_result_params import AidocExoticPicResultParams as AidocExoticPicResultParams
from .aidoc_exotic_question_response import AidocExoticQuestionResponse as AidocExoticQuestionResponse
from .aidoc_if_continue_ask_response import AidocIfContinueAskResponse as AidocIfContinueAskResponse
from .aipic_exotic_pic_result_params import AipicExoticPicResultParams as AipicExoticPicResultParams
from .magnum_key_voice_choice_params import MagnumKeyVoiceChoiceParams as MagnumKeyVoiceChoiceParams
from .medical_record_retrieve_params import MedicalRecordRetrieveParams as MedicalRecordRetrieveParams
from .point_detail_retrieve_response import PointDetailRetrieveResponse as PointDetailRetrieveResponse
from .upload_image_oss_create_params import UploadImageOssCreateParams as UploadImageOssCreateParams
from .aidoc_exotic_report_task_params import AidocExoticReportTaskParams as AidocExoticReportTaskParams
from .aipic_exotic_report_task_params import AipicExoticReportTaskParams as AipicExoticReportTaskParams
from .whitelist_filtering_data_params import WhitelistFilteringDataParams as WhitelistFilteringDataParams
from .ai_checkup_update_profile_params import AICheckupUpdateProfileParams as AICheckupUpdateProfileParams
from .aidoc_exotic_ask_continue_params import AidocExoticAskContinueParams as AidocExoticAskContinueParams
from .evaluation_put_evaluation_params import EvaluationPutEvaluationParams as EvaluationPutEvaluationParams
from .magnum_key_picture_choice_params import MagnumKeyPictureChoiceParams as MagnumKeyPictureChoiceParams
from .magnum_key_voice_question_params import MagnumKeyVoiceQuestionParams as MagnumKeyVoiceQuestionParams
from .medical_record_retrieve_response import MedicalRecordRetrieveResponse as MedicalRecordRetrieveResponse
from .ai_checkup_question_result_params import AICheckupQuestionResultParams as AICheckupQuestionResultParams
from .ai_checkup_session_start_response import AICheckupSessionStartResponse as AICheckupSessionStartResponse
from .aidoc_exotic_if_need_image_params import AidocExoticIfNeedImageParams as AidocExoticIfNeedImageParams
from .medical_record_create_list_params import MedicalRecordCreateListParams as MedicalRecordCreateListParams
from .medication_analysis_report_params import MedicationAnalysisReportParams as MedicationAnalysisReportParams
from .ai_checkup_update_profile_response import AICheckupUpdateProfileResponse as AICheckupUpdateProfileResponse
from .aidoc_exotic_ask_continue_response import AidocExoticAskContinueResponse as AidocExoticAskContinueResponse
from .magnum_key_picture_question_params import MagnumKeyPictureQuestionParams as MagnumKeyPictureQuestionParams
from .medication_analysis_summary_params import MedicationAnalysisSummaryParams as MedicationAnalysisSummaryParams
from .medical_record_create_list_response import MedicalRecordCreateListResponse as MedicalRecordCreateListResponse
from .medical_record_ongoing_record_params import MedicalRecordOngoingRecordParams as MedicalRecordOngoingRecordParams
from .medication_analysis_pic_result_params import (
    MedicationAnalysisPicResultParams as MedicationAnalysisPicResultParams,
)
from .user_module_usage_get_add_wecome_bonus_params import (
    UserModuleUsageGetAddWecomeBonusParams as UserModuleUsageGetAddWecomeBonusParams,
)
from .user_module_usage_get_add_wecome_bonus_response import (
    UserModuleUsageGetAddWecomeBonusResponse as UserModuleUsageGetAddWecomeBonusResponse,
)
from .user_module_usage_get_wechat_mini_qrcode_response import (
    UserModuleUsageGetWechatMiniQrcodeResponse as UserModuleUsageGetWechatMiniQrcodeResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from .._types import FileTypes

__all__ = ["UploadImageCreateParams"]


class UploadImageCreateParams(TypedDict, total=False):
    image: Required[FileTypes]
    """要上传的图片文件"""

    is_to_cloud: int
    """是否上传到图床"""

    upload_type: Literal[1, 2, 3, 4]
    """图片上传类型 1-头像 2-图片识别模块 3-表情包 4-其他"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAidoc:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_if_continue_ask(self, client: Czlai) -> None:
        aidoc = client.aidoc.if_continue_ask()
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_if_continue_ask_with_all_params(self, client: Czlai) -> None:
        aidoc = client.aidoc.if_continue_ask(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_if_continue_ask(self, client: Czlai) -> None:
        response = client.aidoc.with_raw_response.if_continue_ask()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = response.parse()
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_if_continue_ask(self, client: Czlai) -> None:
        with client.aidoc.with_streaming_response.if_continue_ask() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = response.parse()
            assert_matches_type(str, aidoc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_if_need_image(self, client: Czlai) -> None:
        aidoc = client.aidoc.if_need_image()
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    def test_method_if_need_image_with_all_params(self, client: Czlai) -> None:
        aidoc = client.aidoc.if_need_image(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    def test_raw_response_if_need_image(self, client: Czlai) -> None:
        response = client.aidoc.with_raw_response.if_need_image()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = response.parse()
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    def test_streaming_response_if_need_image(self, client: Czlai) -> None:
        with client.aidoc.with_streaming_response.if_need_image() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = response.parse()
            assert_matches_type(object, aidoc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_pic_result(self, client: Czlai) -> None:
        aidoc = client.aidoc.pic_result()
        assert aidoc is None

    @parametrize
    def test_method_pic_result_with_all_params(self, client: Czlai) -> None:
        aidoc = client.aidoc.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    def test_raw_response_pic_result(self, client: Czlai) -> None:
        response = client.aidoc.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = response.parse()
        assert aidoc is None

    @parametrize
    def test_streaming_response_pic_result(self, client: Czlai) -> None:
        with client.aidoc.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        aidoc = client.aidoc.report(
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.aidoc.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = response.parse()
        assert aidoc is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.aidoc.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report_task(self, client: Czlai) -> None:
        aidoc = client.aidoc.report_task(
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    def test_method_report_task_with_all_params(self, client: Czlai) -> None:
        aidoc = client.aidoc.report_task(
            session_id="session_id",
            report_type=0,
        )
        assert aidoc is None

    @parametrize
    def test_raw_response_report_task(self, client: Czlai) -> None:
        response = client.aidoc.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = response.parse()
        assert aidoc is None

    @parametrize
    def test_streaming_response_report_task(self, client: Czlai) -> None:
        with client.aidoc.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAidoc:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_if_continue_ask(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.if_continue_ask()
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_if_continue_ask_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.if_continue_ask(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_if_continue_ask(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc.with_raw_response.if_continue_ask()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = await response.parse()
        assert_matches_type(str, aidoc, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_if_continue_ask(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc.with_streaming_response.if_continue_ask() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = await response.parse()
            assert_matches_type(str, aidoc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_if_need_image(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.if_need_image()
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    async def test_method_if_need_image_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.if_need_image(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    async def test_raw_response_if_need_image(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc.with_raw_response.if_need_image()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = await response.parse()
        assert_matches_type(object, aidoc, path=["response"])

    @parametrize
    async def test_streaming_response_if_need_image(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc.with_streaming_response.if_need_image() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = await response.parse()
            assert_matches_type(object, aidoc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_pic_result(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.pic_result()
        assert aidoc is None

    @parametrize
    async def test_method_pic_result_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.pic_result(
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    async def test_raw_response_pic_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = await response.parse()
        assert aidoc is None

    @parametrize
    async def test_streaming_response_pic_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = await response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.report(
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc.with_raw_response.report(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = await response.parse()
        assert aidoc is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc.with_streaming_response.report(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = await response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report_task(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.report_task(
            session_id="session_id",
        )
        assert aidoc is None

    @parametrize
    async def test_method_report_task_with_all_params(self, async_client: AsyncCzlai) -> None:
        aidoc = await async_client.aidoc.report_task(
            session_id="session_id",
            report_type=0,
        )
        assert aidoc is None

    @parametrize
    async def test_raw_response_report_task(self, async_client: AsyncCzlai) -> None:
        response = await async_client.aidoc.with_raw_response.report_task(
            session_id="session_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        aidoc = await response.parse()
        assert aidoc is None

    @parametrize
    async def test_streaming_response_report_task(self, async_client: AsyncCzlai) -> None:
        async with async_client.aidoc.with_streaming_response.report_task(
            session_id="session_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            aidoc = await response.parse()
            assert aidoc is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AIMemeCreateParams"]


class AIMemeCreateParams(TypedDict, total=False):
    image_url: str
    """图片地址"""

    session_id: str
    """会话 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["MedicalRecordOngoingRecordParams"]


class MedicalRecordOngoingRecordParams(TypedDict, total=False):
    module_type: Required[int]
    """模块类型 1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别"""

    pet_profile_id: Required[int]
    """宠物档案 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    aidoc_report_params,
    aidoc_pic_result_params,
    aidoc_report_task_params,
    aidoc_if_need_image_params,
    aidoc_if_continue_ask_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AidocResource", "AsyncAidocResource"]


class AidocResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AidocResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AidocResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AidocResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AidocResourceWithStreamingResponse(self)

    def if_continue_ask(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        判断是否需要继续提问

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/aidoc/if-continue-ask",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_if_continue_ask_params.AidocIfContinueAskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def if_need_image(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        判断是否需要传图

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/aidoc/if-need-image",
            body=maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_if_need_image_params.AidocIfNeedImageParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def pic_result(
        self,
        *,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果(流式)

        Args:
          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aidoc/pic-result",
            body=maybe_transform(
                {
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_pic_result_params.AidocPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report(
        self,
        *,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        发布获取诊断报告任务

        Args:
          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aidoc/report",
            body=maybe_transform({"session_id": session_id}, aidoc_report_params.AidocReportParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def report_task(
        self,
        *,
        session_id: str,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/aidoc/report-task",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "report_type": report_type,
                },
                aidoc_report_task_params.AidocReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAidocResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAidocResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAidocResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAidocResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAidocResourceWithStreamingResponse(self)

    async def if_continue_ask(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        判断是否需要继续提问

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/aidoc/if-continue-ask",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_if_continue_ask_params.AidocIfContinueAskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def if_need_image(
        self,
        *,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        判断是否需要传图

        Args:
          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/aidoc/if-need-image",
            body=await async_maybe_transform(
                {
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_if_need_image_params.AidocIfNeedImageParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def pic_result(
        self,
        *,
        img_url: str | NotGiven = NOT_GIVEN,
        pet_profile_id: int | NotGiven = NOT_GIVEN,
        session_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取图片结果(流式)

        Args:
          img_url: 图片 url

          pet_profile_id: 宠物档案 id

          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aidoc/pic-result",
            body=await async_maybe_transform(
                {
                    "img_url": img_url,
                    "pet_profile_id": pet_profile_id,
                    "session_id": session_id,
                },
                aidoc_pic_result_params.AidocPicResultParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report(
        self,
        *,
        session_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        发布获取诊断报告任务

        Args:
          session_id: 会话 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aidoc/report",
            body=await async_maybe_transform({"session_id": session_id}, aidoc_report_params.AidocReportParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def report_task(
        self,
        *,
        session_id: str,
        report_type: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取诊断报告

        Args:
          session_id: 会话 id

          report_type: 报告类型

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/aidoc/report-task",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "report_type": report_type,
                },
                aidoc_report_task_params.AidocReportTaskParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AidocResourceWithRawResponse:
    def __init__(self, aidoc: AidocResource) -> None:
        self._aidoc = aidoc

        self.if_continue_ask = to_raw_response_wrapper(
            aidoc.if_continue_ask,
        )
        self.if_need_image = to_raw_response_wrapper(
            aidoc.if_need_image,
        )
        self.pic_result = to_raw_response_wrapper(
            aidoc.pic_result,
        )
        self.report = to_raw_response_wrapper(
            aidoc.report,
        )
        self.report_task = to_raw_response_wrapper(
            aidoc.report_task,
        )


class AsyncAidocResourceWithRawResponse:
    def __init__(self, aidoc: AsyncAidocResource) -> None:
        self._aidoc = aidoc

        self.if_continue_ask = async_to_raw_response_wrapper(
            aidoc.if_continue_ask,
        )
        self.if_need_image = async_to_raw_response_wrapper(
            aidoc.if_need_image,
        )
        self.pic_result = async_to_raw_response_wrapper(
            aidoc.pic_result,
        )
        self.report = async_to_raw_response_wrapper(
            aidoc.report,
        )
        self.report_task = async_to_raw_response_wrapper(
            aidoc.report_task,
        )


class AidocResourceWithStreamingResponse:
    def __init__(self, aidoc: AidocResource) -> None:
        self._aidoc = aidoc

        self.if_continue_ask = to_streamed_response_wrapper(
            aidoc.if_continue_ask,
        )
        self.if_need_image = to_streamed_response_wrapper(
            aidoc.if_need_image,
        )
        self.pic_result = to_streamed_response_wrapper(
            aidoc.pic_result,
        )
        self.report = to_streamed_response_wrapper(
            aidoc.report,
        )
        self.report_task = to_streamed_response_wrapper(
            aidoc.report_task,
        )


class AsyncAidocResourceWithStreamingResponse:
    def __init__(self, aidoc: AsyncAidocResource) -> None:
        self._aidoc = aidoc

        self.if_continue_ask = async_to_streamed_response_wrapper(
            aidoc.if_continue_ask,
        )
        self.if_need_image = async_to_streamed_response_wrapper(
            aidoc.if_need_image,
        )
        self.pic_result = async_to_streamed_response_wrapper(
            aidoc.pic_result,
        )
        self.report = async_to_streamed_response_wrapper(
            aidoc.report,
        )
        self.report_task = async_to_streamed_response_wrapper(
            aidoc.report_task,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import ai_conv_answer_params, ai_conv_relation_params, ai_conv_validate_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["AIConvResource", "AsyncAIConvResource"]


class AIConvResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AIConvResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AIConvResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AIConvResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AIConvResourceWithStreamingResponse(self)

    def answer(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        AI 聊天

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/ai-conv/answer",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_answer_params.AIConvAnswerParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def relation(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取联想

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-conv/relation",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_relation_params.AIConvRelationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def validate(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        AI 聊天校验

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/ai-conv/validate",
            body=maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_validate_params.AIConvValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAIConvResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAIConvResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAIConvResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAIConvResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncAIConvResourceWithStreamingResponse(self)

    async def answer(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        AI 聊天

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/ai-conv/answer",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_answer_params.AIConvAnswerParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def relation(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        获取联想

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-conv/relation",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_relation_params.AIConvRelationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def validate(
        self,
        *,
        session_id: str | NotGiven = NOT_GIVEN,
        user_input: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        AI 聊天校验

        Args:
          session_id: 会话 id

          user_input: 用户输入

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/ai-conv/validate",
            body=await async_maybe_transform(
                {
                    "session_id": session_id,
                    "user_input": user_input,
                },
                ai_conv_validate_params.AIConvValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AIConvResourceWithRawResponse:
    def __init__(self, ai_conv: AIConvResource) -> None:
        self._ai_conv = ai_conv

        self.answer = to_raw_response_wrapper(
            ai_conv.answer,
        )
        self.relation = to_raw_response_wrapper(
            ai_conv.relation,
        )
        self.validate = to_raw_response_wrapper(
            ai_conv.validate,
        )


class AsyncAIConvResourceWithRawResponse:
    def __init__(self, ai_conv: AsyncAIConvResource) -> None:
        self._ai_conv = ai_conv

        self.answer = async_to_raw_response_wrapper(
            ai_conv.answer,
        )
        self.relation = async_to_raw_response_wrapper(
            ai_conv.relation,
        )
        self.validate = async_to_raw_response_wrapper(
            ai_conv.validate,
        )


class AIConvResourceWithStreamingResponse:
    def __init__(self, ai_conv: AIConvResource) -> None:
        self._ai_conv = ai_conv

        self.answer = to_streamed_response_wrapper(
            ai_conv.answer,
        )
        self.relation = to_streamed_response_wrapper(
            ai_conv.relation,
        )
        self.validate = to_streamed_response_wrapper(
            ai_conv.validate,
        )


class AsyncAIConvResourceWithStreamingResponse:
    def __init__(self, ai_conv: AsyncAIConvResource) -> None:
        self._ai_conv = ai_conv

        self.answer = async_to_streamed_response_wrapper(
            ai_conv.answer,
        )
        self.relation = async_to_streamed_response_wrapper(
            ai_conv.relation,
        )
        self.validate = async_to_streamed_response_wrapper(
            ai_conv.validate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UserModuleUsageGetAddWecomeBonusParams"]


class UserModuleUsageGetAddWecomeBonusParams(TypedDict, total=False):
    module_type: int
    """1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UserPointCostReportParams"]


class UserPointCostReportParams(TypedDict, total=False):
    item_key: str

    medical_record_id: int
    """病历 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .asr_create_params import AsrCreateParams as AsrCreateParams
from .contact_create_params import ContactCreateParams as ContactCreateParams
from .summary_create_params import SummaryCreateParams as SummaryCreateParams
from .user_info_retrieve_params import UserInfoRetrieveParams as UserInfoRetrieveParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import whitelist_save_data_params, whitelist_filtering_data_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["WhitelistResource", "AsyncWhitelistResource"]


class WhitelistResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WhitelistResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return WhitelistResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WhitelistResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return WhitelistResourceWithStreamingResponse(self)

    def filtering_data(
        self,
        *,
        filtering_data: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        白名单数据过滤

        Args:
          filtering_data: 过滤数据

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/whitelist/filtering_data",
            body=maybe_transform(
                {"filtering_data": filtering_data}, whitelist_filtering_data_params.WhitelistFilteringDataParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def save_data(
        self,
        *,
        save_data: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        白名单数据保存

        Args:
          save_data: 保存数据

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/whitelist/save_data",
            body=maybe_transform({"save_data": save_data}, whitelist_save_data_params.WhitelistSaveDataParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncWhitelistResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWhitelistResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWhitelistResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWhitelistResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncWhitelistResourceWithStreamingResponse(self)

    async def filtering_data(
        self,
        *,
        filtering_data: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        白名单数据过滤

        Args:
          filtering_data: 过滤数据

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/whitelist/filtering_data",
            body=await async_maybe_transform(
                {"filtering_data": filtering_data}, whitelist_filtering_data_params.WhitelistFilteringDataParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def save_data(
        self,
        *,
        save_data: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        白名单数据保存

        Args:
          save_data: 保存数据

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/whitelist/save_data",
            body=await async_maybe_transform(
                {"save_data": save_data}, whitelist_save_data_params.WhitelistSaveDataParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class WhitelistResourceWithRawResponse:
    def __init__(self, whitelist: WhitelistResource) -> None:
        self._whitelist = whitelist

        self.filtering_data = to_raw_response_wrapper(
            whitelist.filtering_data,
        )
        self.save_data = to_raw_response_wrapper(
            whitelist.save_data,
        )


class AsyncWhitelistResourceWithRawResponse:
    def __init__(self, whitelist: AsyncWhitelistResource) -> None:
        self._whitelist = whitelist

        self.filtering_data = async_to_raw_response_wrapper(
            whitelist.filtering_data,
        )
        self.save_data = async_to_raw_response_wrapper(
            whitelist.save_data,
        )


class WhitelistResourceWithStreamingResponse:
    def __init__(self, whitelist: WhitelistResource) -> None:
        self._whitelist = whitelist

        self.filtering_data = to_streamed_response_wrapper(
            whitelist.filtering_data,
        )
        self.save_data = to_streamed_response_wrapper(
            whitelist.save_data,
        )


class AsyncWhitelistResourceWithStreamingResponse:
    def __init__(self, whitelist: AsyncWhitelistResource) -> None:
        self._whitelist = whitelist

        self.filtering_data = async_to_streamed_response_wrapper(
            whitelist.filtering_data,
        )
        self.save_data = async_to_streamed_response_wrapper(
            whitelist.save_data,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestContact:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Czlai) -> None:
        contact = client.users.contact.create()
        assert contact is None

    @parametrize
    def test_method_create_with_all_params(self, client: Czlai) -> None:
        contact = client.users.contact.create(
            company_name="company_name",
            contact_name="contact_name",
            mobile="mobile",
        )
        assert contact is None

    @parametrize
    def test_raw_response_create(self, client: Czlai) -> None:
        response = client.users.contact.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        contact = response.parse()
        assert contact is None

    @parametrize
    def test_streaming_response_create(self, client: Czlai) -> None:
        with client.users.contact.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            contact = response.parse()
            assert contact is None

        assert cast(Any, response.is_closed) is True


class TestAsyncContact:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncCzlai) -> None:
        contact = await async_client.users.contact.create()
        assert contact is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCzlai) -> None:
        contact = await async_client.users.contact.create(
            company_name="company_name",
            contact_name="contact_name",
            mobile="mobile",
        )
        assert contact is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCzlai) -> None:
        response = await async_client.users.contact.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        contact = await response.parse()
        assert contact is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCzlai) -> None:
        async with async_client.users.contact.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            contact = await response.parse()
            assert contact is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import point_task_bonus_params, point_task_confirm_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.point_task_list_response import PointTaskListResponse

__all__ = ["PointTasksResource", "AsyncPointTasksResource"]


class PointTasksResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PointTasksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return PointTasksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PointTasksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return PointTasksResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PointTaskListResponse:
        """获取积分任务列表"""
        return self._get(
            "/point-task",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PointTaskListResponse,
        )

    def bonus(
        self,
        *,
        task_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        领取奖励

        Args:
          task_id: 任务 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/point-task/bonus",
            body=maybe_transform({"task_id": task_id}, point_task_bonus_params.PointTaskBonusParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def confirm(
        self,
        *,
        task_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        确认积分任务

        Args:
          task_id: 任务 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/point-task/confirm",
            body=maybe_transform({"task_id": task_id}, point_task_confirm_params.PointTaskConfirmParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncPointTasksResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPointTasksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPointTasksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPointTasksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncPointTasksResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PointTaskListResponse:
        """获取积分任务列表"""
        return await self._get(
            "/point-task",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PointTaskListResponse,
        )

    async def bonus(
        self,
        *,
        task_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        领取奖励

        Args:
          task_id: 任务 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/point-task/bonus",
            body=await async_maybe_transform({"task_id": task_id}, point_task_bonus_params.PointTaskBonusParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def confirm(
        self,
        *,
        task_id: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        确认积分任务

        Args:
          task_id: 任务 id

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/point-task/confirm",
            body=await async_maybe_transform({"task_id": task_id}, point_task_confirm_params.PointTaskConfirmParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class PointTasksResourceWithRawResponse:
    def __init__(self, point_tasks: PointTasksResource) -> None:
        self._point_tasks = point_tasks

        self.list = to_raw_response_wrapper(
            point_tasks.list,
        )
        self.bonus = to_raw_response_wrapper(
            point_tasks.bonus,
        )
        self.confirm = to_raw_response_wrapper(
            point_tasks.confirm,
        )


class AsyncPointTasksResourceWithRawResponse:
    def __init__(self, point_tasks: AsyncPointTasksResource) -> None:
        self._point_tasks = point_tasks

        self.list = async_to_raw_response_wrapper(
            point_tasks.list,
        )
        self.bonus = async_to_raw_response_wrapper(
            point_tasks.bonus,
        )
        self.confirm = async_to_raw_response_wrapper(
            point_tasks.confirm,
        )


class PointTasksResourceWithStreamingResponse:
    def __init__(self, point_tasks: PointTasksResource) -> None:
        self._point_tasks = point_tasks

        self.list = to_streamed_response_wrapper(
            point_tasks.list,
        )
        self.bonus = to_streamed_response_wrapper(
            point_tasks.bonus,
        )
        self.confirm = to_streamed_response_wrapper(
            point_tasks.confirm,
        )


class AsyncPointTasksResourceWithStreamingResponse:
    def __init__(self, point_tasks: AsyncPointTasksResource) -> None:
        self._point_tasks = point_tasks

        self.list = async_to_streamed_response_wrapper(
            point_tasks.list,
        )
        self.bonus = async_to_streamed_response_wrapper(
            point_tasks.bonus,
        )
        self.confirm = async_to_streamed_response_wrapper(
            point_tasks.confirm,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SessionRecordHistoryParams"]


class SessionRecordHistoryParams(TypedDict, total=False):
    content: Required[str]
    """内容"""

    module_type: Required[int]
    """1-智能问诊 2-健康检测 3-用药分析 4-知识问答 5-图像识别"""

    role: Required[str]
    """角色, 取值为其中之一 ==>[user, ai]"""

    session_id: Required[str]
    """会话 id"""

    content_type: int
    """1-文字 2-图文"""

    stage: int
    """1-用户主诉 2-用户回答 3-AI 提问 4-AI 病情小结 5-AI 病例报告 6-AI 输出 7-用户补充"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["AIConvAnswerParams"]


class AIConvAnswerParams(TypedDict, total=False):
    session_id: str
    """会话 id"""

    user_input: str
    """用户输入"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMedicationAnalysis:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_pic_result(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.pic_result()
        assert medication_analysis is None

    @parametrize
    def test_method_pic_result_with_all_params(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.pic_result(
            img_belong=0,
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    def test_raw_response_pic_result(self, client: Czlai) -> None:
        response = client.medication_analysis.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = response.parse()
        assert medication_analysis is None

    @parametrize
    def test_streaming_response_pic_result(self, client: Czlai) -> None:
        with client.medication_analysis.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_report(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.report()
        assert medication_analysis is None

    @parametrize
    def test_method_report_with_all_params(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.report(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    def test_raw_response_report(self, client: Czlai) -> None:
        response = client.medication_analysis.with_raw_response.report()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = response.parse()
        assert medication_analysis is None

    @parametrize
    def test_streaming_response_report(self, client: Czlai) -> None:
        with client.medication_analysis.with_streaming_response.report() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_summary(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.summary()
        assert medication_analysis is None

    @parametrize
    def test_method_summary_with_all_params(self, client: Czlai) -> None:
        medication_analysis = client.medication_analysis.summary(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    def test_raw_response_summary(self, client: Czlai) -> None:
        response = client.medication_analysis.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = response.parse()
        assert medication_analysis is None

    @parametrize
    def test_streaming_response_summary(self, client: Czlai) -> None:
        with client.medication_analysis.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True


class TestAsyncMedicationAnalysis:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_pic_result(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.pic_result()
        assert medication_analysis is None

    @parametrize
    async def test_method_pic_result_with_all_params(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.pic_result(
            img_belong=0,
            img_url="img_url",
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    async def test_raw_response_pic_result(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medication_analysis.with_raw_response.pic_result()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = await response.parse()
        assert medication_analysis is None

    @parametrize
    async def test_streaming_response_pic_result(self, async_client: AsyncCzlai) -> None:
        async with async_client.medication_analysis.with_streaming_response.pic_result() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = await response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_report(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.report()
        assert medication_analysis is None

    @parametrize
    async def test_method_report_with_all_params(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.report(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    async def test_raw_response_report(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medication_analysis.with_raw_response.report()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = await response.parse()
        assert medication_analysis is None

    @parametrize
    async def test_streaming_response_report(self, async_client: AsyncCzlai) -> None:
        async with async_client.medication_analysis.with_streaming_response.report() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = await response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_summary(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.summary()
        assert medication_analysis is None

    @parametrize
    async def test_method_summary_with_all_params(self, async_client: AsyncCzlai) -> None:
        medication_analysis = await async_client.medication_analysis.summary(
            pet_profile_id=0,
            session_id="session_id",
        )
        assert medication_analysis is None

    @parametrize
    async def test_raw_response_summary(self, async_client: AsyncCzlai) -> None:
        response = await async_client.medication_analysis.with_raw_response.summary()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        medication_analysis = await response.parse()
        assert medication_analysis is None

    @parametrize
    async def test_streaming_response_summary(self, async_client: AsyncCzlai) -> None:
        async with async_client.medication_analysis.with_streaming_response.summary() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            medication_analysis = await response.parse()
            assert medication_analysis is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from czlai import Czlai, AsyncCzlai
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAIConv:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_answer(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.answer()
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_method_answer_with_all_params(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.answer(
            session_id="session_id",
            user_input="user_input",
        )
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_raw_response_answer(self, client: Czlai) -> None:
        response = client.ai_conv.with_raw_response.answer()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = response.parse()
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    def test_streaming_response_answer(self, client: Czlai) -> None:
        with client.ai_conv.with_streaming_response.answer() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = response.parse()
            assert_matches_type(str, ai_conv, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_relation(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.relation()
        assert ai_conv is None

    @parametrize
    def test_method_relation_with_all_params(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.relation(
            session_id="session_id",
            user_input="user_input",
        )
        assert ai_conv is None

    @parametrize
    def test_raw_response_relation(self, client: Czlai) -> None:
        response = client.ai_conv.with_raw_response.relation()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = response.parse()
        assert ai_conv is None

    @parametrize
    def test_streaming_response_relation(self, client: Czlai) -> None:
        with client.ai_conv.with_streaming_response.relation() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = response.parse()
            assert ai_conv is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_validate(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.validate()
        assert ai_conv is None

    @parametrize
    def test_method_validate_with_all_params(self, client: Czlai) -> None:
        ai_conv = client.ai_conv.validate(
            session_id="session_id",
            user_input="user_input",
        )
        assert ai_conv is None

    @parametrize
    def test_raw_response_validate(self, client: Czlai) -> None:
        response = client.ai_conv.with_raw_response.validate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = response.parse()
        assert ai_conv is None

    @parametrize
    def test_streaming_response_validate(self, client: Czlai) -> None:
        with client.ai_conv.with_streaming_response.validate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = response.parse()
            assert ai_conv is None

        assert cast(Any, response.is_closed) is True


class TestAsyncAIConv:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_answer(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.answer()
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_method_answer_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.answer(
            session_id="session_id",
            user_input="user_input",
        )
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_raw_response_answer(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_conv.with_raw_response.answer()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = await response.parse()
        assert_matches_type(str, ai_conv, path=["response"])

    @pytest.mark.skip(
        reason="currently no good way to test endpoints with content type text/event-stream, Prism mock server will fail"
    )
    @parametrize
    async def test_streaming_response_answer(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_conv.with_streaming_response.answer() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = await response.parse()
            assert_matches_type(str, ai_conv, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_relation(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.relation()
        assert ai_conv is None

    @parametrize
    async def test_method_relation_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.relation(
            session_id="session_id",
            user_input="user_input",
        )
        assert ai_conv is None

    @parametrize
    async def test_raw_response_relation(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_conv.with_raw_response.relation()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = await response.parse()
        assert ai_conv is None

    @parametrize
    async def test_streaming_response_relation(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_conv.with_streaming_response.relation() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = await response.parse()
            assert ai_conv is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_validate(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.validate()
        assert ai_conv is None

    @parametrize
    async def test_method_validate_with_all_params(self, async_client: AsyncCzlai) -> None:
        ai_conv = await async_client.ai_conv.validate(
            session_id="session_id",
            user_input="user_input",
        )
        assert ai_conv is None

    @parametrize
    async def test_raw_response_validate(self, async_client: AsyncCzlai) -> None:
        response = await async_client.ai_conv.with_raw_response.validate()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ai_conv = await response.parse()
        assert ai_conv is None

    @parametrize
    async def test_streaming_response_validate(self, async_client: AsyncCzlai) -> None:
        async with async_client.ai_conv.with_streaming_response.validate() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ai_conv = await response.parse()
            assert ai_conv is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["EvaluationPutEvaluationParams"]


class EvaluationPutEvaluationParams(TypedDict, total=False):
    content: Required[str]
    """文本内容"""

    evaluation: Required[int]
    """评价 id"""

    session_id: Required[str]
    """会话 id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .is_add_wecome_retrieve_response import IsAddWecomeRetrieveResponse as IsAddWecomeRetrieveResponse
